==> invoice-client-4.1.12-20201012.074128-2-sources.jar: com/xforceplus/seller/invoice/client/model/MakeOutSuccessMsg.java <==
package com.xforceplus.seller.invoice.client.model;

import java.util.List;

public class MakeOutSuccessMsg {

    private Integer invoiceOrigin;

    private Long preInvoiceId;

    private Long invoiceId;

    private Long batchNo;

    private List<DetailInfo> detailInfoList;

    private String invoiceCode;

    private String invoiceNo;

    public Long getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(Long batchNo) {
        this.batchNo = batchNo;
    }

    public List<DetailInfo> getDetailInfoList() {
        return detailInfoList;
    }

    public void setDetailInfoList(List<DetailInfo> detailInfoList) {
        this.detailInfoList = detailInfoList;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public Long getPreInvoiceId() {
        return preInvoiceId;
    }

    public void setPreInvoiceId(Long preInvoiceId) {
        this.preInvoiceId = preInvoiceId;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    @Override
    public String toString() {
        return "NoticeBillMsg{" +
                "preInvoiceId=" + preInvoiceId +
                ", invoiceId=" + invoiceId +
                ", batchNo=" + batchNo +
                ", detailInfoList=" + detailInfoList +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", invoiceNo='" + invoiceNo + '\'' +
                '}';
    }

    public Integer getInvoiceOrigin() {
        return invoiceOrigin;
    }

    public void setInvoiceOrigin(Integer invoiceOrigin) {
        this.invoiceOrigin = invoiceOrigin;
    }
}

==> invoice-client-4.1.42-20221026.091035-14-sources.jar: com/xforceplus/seller/invoice/client/model/MakeOutSuccessMsg.java <==
package com.xforceplus.seller.invoice.client.model;

import java.util.List;

public class MakeOutSuccessMsg {

    private Integer invoiceOrigin;

    private Long preInvoiceId;

    private Long invoiceId;

    private Long batchNo;

    private List<DetailInfo> detailInfoList;

    private String invoiceCode;

    private String invoiceNo;

    /**
     * 回写单据后需 1-下发协同 0-不下发协同, 默认下发
     */
    private Integer cooperationFlag = 1;

    public Long getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(Long batchNo) {
        this.batchNo = batchNo;
    }

    public List<DetailInfo> getDetailInfoList() {
        return detailInfoList;
    }

    public void setDetailInfoList(List<DetailInfo> detailInfoList) {
        this.detailInfoList = detailInfoList;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public Long getPreInvoiceId() {
        return preInvoiceId;
    }

    public void setPreInvoiceId(Long preInvoiceId) {
        this.preInvoiceId = preInvoiceId;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public Integer getCooperationFlag() {
        return cooperationFlag;
    }

    public void setCooperationFlag(Integer cooperationFlag) {
        this.cooperationFlag = cooperationFlag;
    }

    @Override
    public String toString() {
        return "NoticeBillMsg{" +
                "preInvoiceId=" + preInvoiceId +
                ", invoiceId=" + invoiceId +
                ", batchNo=" + batchNo +
                ", detailInfoList=" + detailInfoList +
                ", invoiceCode='" + invoiceCode + '\'' +
                ", invoiceNo='" + invoiceNo + '\'' +
                ", cooperationFlag='" + cooperationFlag + '\'' +
                '}';
    }

    public Integer getInvoiceOrigin() {
        return invoiceOrigin;
    }

    public void setInvoiceOrigin(Integer invoiceOrigin) {
        this.invoiceOrigin = invoiceOrigin;
    }
}
